@@ -1,4 +1,4 @@
-# Copyrights 1998,2005-2016 by [Mark Overmeer].
+# Copyrights 1998,2005-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -7,7 +7,7 @@ use strict;
 
 package CPAN::Site::Index;
 use vars '$VERSION';
-$VERSION = '1.13';
+$VERSION = '1.14';
 
 use base 'Exporter';
 
@@ -263,9 +263,9 @@ sub collect_package_details($$$)
         next if $in_pod || m/^\s*#/;
 
         $_ .= shift @lines
-            while @lines && m/package|use|VERSION/ && !m/\;/;
+            while @lines && m/package|use|VERSION/ && !m/[;{]/;
 
-        if( m/^\s* package \s* ((?:\w+\:\:)*\w+) (?:\s+ (\S*))? \s* ;/x )
+        if( m/^\s* package \s* ((?:\w+\:\:)*\w+) (?:\s+ (\S*))? \s* [;{]/x )
         {   my ($thispkg, $v) = ($1, $2);
             my $thisversion;
             if($v)
@@ -282,7 +282,11 @@ sub collect_package_details($$$)
             trace "pkg $package from $fn";
         }
 
-        if( m/^ (?:use\s+version\s*;\s*)?
+        if( m/^\s* \$ ${package}::VERSION \s* = \s* ["']?(\w+?)["']? \s* ;/x )
+        {   $VERSION = $1;
+        }
+
+        if( !$VERSION && m/^ (?:use\s+version\s*;\s*)?
             (?:our)? \s* \$ ((?: \w+\:\:)*) VERSION \s* \= (.*)/x )
         {   defined $2 or next;
             my ($ns, $vers) = ($1, $2);
